==> anarchism_15.0.orig.tar.gz: afaq-15.0/markdown/append13int.md <==
# Appendix - Is "anarcho"-capitalism a type of anarchism?

Anyone who has followed political discussion on the net has probably come
across people calling themselves libertarians but arguing from a right-wing,
pro-capitalist perspective. For most Europeans this is weird, as in Europe the
term _"libertarian"_ is almost always used in conjunction with _"socialist"_
or _"communist."_ In the US, though, the Right has partially succeeded in
appropriating this term for itself. Even stranger, however, is that a few of
these right-wingers have started calling themselves "anarchists" in what must
be one of the finest examples of an oxymoron in the English language:
'Anarcho-capitalist'!!

Arguing with fools is seldom rewarded, but to allow their foolishness to go
unchallenged risks allowing them to deceive those who are new to anarchism.
That's what this section of the anarchist FAQ is for, to show why the claims
of these "anarchist" capitalists are false. Anarchism has always been anti-
capitalist and any "anarchism" that claims otherwise cannot be part of the
anarchist tradition. So this section of the FAQ does not reflect some kind of
debate within anarchism, as many of these types like to pretend, but a debate
between anarchism and its old enemy, capitalism. In many ways this debate
mirrors the one between Peter Kropotkin and Herbert Spencer, an English pro-
capitalist, minimal statist, at the turn the 19th century and, as such, it is
hardly new.

The "anarcho"-capitalist argument hinges on using the dictionary definition of
"anarchism" and/or "anarchy" - they try to define anarchism as being
"opposition to government," and nothing else. However, dictionaries are hardly
politically sophisticated and their definitions rarely reflect the wide range
of ideas associated with political theories and their history. Thus the
dictionary "definition" is anarchism will tend to ignore its consistent views
on authority, exploitation, property and capitalism (ideas easily discovered
if actual anarchist texts are read). And, of course, many dictionaries
"define" anarchy as "chaos" or "disorder" but we never see
"anarcho"-capitalists use that particular definition!

And for this strategy to work, a lot of "inconvenient" history and ideas from
all branches of anarchism must be ignored. From individualists like Spooner
and Tucker to communists like Kropotkin and Malatesta, anarchists have always
been anti-capitalist (see [ section G](secGcon.html) for more on the anti-
capitalist nature of individualist anarchism). Therefore "anarcho"-capitalists
are not anarchists in the same sense that rain is not dry.

Of course, we cannot stop the "anarcho"-capitalists using the words "anarcho",
"anarchism" and "anarchy" to describe their ideas. The democracies of the west
could not stop the Chinese Stalinist state calling itself the People's
Republic of China. Nor could the social democrats stop the fascists in Germany
calling themselves "National Socialists". Nor could the Italian anarcho-
syndicalists stop the fascists using the expression "National Syndicalism".
This does not mean that any of these movements actual name reflected their
content -- China is a dictatorship, not a democracy, the Nazi's were not
socialists (capitalists made fortunes in Nazi Germany because it crushed the
labour movement), and the Italian fascist state had nothing in common with
anarcho-syndicalists ideas of decentralised, "from the bottom up" unions and
the abolition of the state and capitalism.

Therefore, just because someone uses a label it does not mean that they
support the ideas associated with that label. And this is the case with
"anarcho"-capitalism -- its ideas are at odds with the key ideas associated
with all forms of traditional anarchism (even individualist anarchism which is
often claimed as being a forefather of the ideology).

All we can do is indicate **why** "anarcho"-capitalism is not part of the
anarchist tradition and so has falsely appropriated the name. This section of
the FAQ aims to do just that -- present the case why "anarcho"-capitalists are
not anarchists. We do this, in part, by indicating where they differ from
genuine anarchists (on such essential issues as private property, equality,
exploitation and opposition to hierarchy) In addition, we take the opportunity
to present a general critique of right-libertarian claims from an anarchist
perspective. In this way we show up why anarchists reject that theory as being
opposed to liberty and anarchist ideals.

We are covering this topic in an anarchist FAQ for three reasons. Firstly, the
number of "libertarian" and "anarcho"-capitalists on the net means that those
seeking to find out about anarchism may conclude that they are "anarchists" as
well. Secondly, unfortunately, some academics and writers have taken their
claims of being anarchists at face value and have included their ideology into
general accounts of anarchism. These two reasons are obviously related and
hence the need to show the facts of the matter. As we have extensively
documented in earlier sections, anarchist theory has always been anti-
capitalist. There is no relationship between anarchism and capitalism, in any
form. Therefore, there is a need for this section in order to indicate exactly
why "anarcho"-capitalism is not anarchist. As will be quickly seen from our
discussion, almost all anarchists who become aware of "anarcho"-capitalism
quickly reject it as a form of anarchism (the better academic accounts do note
that anarchists generally reject the claim, though). The last reason is to
provide other anarchists with arguments and evidence to use against
"anarcho"-capitalism and its claims of being a new form of "anarchism."

So this section of the FAQ does not, as we noted above, represent some kind of
"debate" within anarchism. It reflects the attempt by anarchists to reclaim
the history and meaning of anarchism from those who are attempting to steal
its name (just as right-wingers in America have attempted to appropriate the
name "libertarian" for their pro-capitalist views, and by so doing ignore over
100 years of anti-capitalist usage). However, this section also serves two
other purposes. Firstly, critiquing right-libertarian and "anarcho"-capitalist
theories allows us to explain anarchist ones at the same time and indicate why
they are better. Secondly, and more importantly, the "ideas" and "ideals" that
underlie "anarcho"-capitalism are usually identical (or, at the very least,
similar) to those of neo-liberalism. This was noted by Bob Black in the early
1980s, when a _"wing of the Reaganist Right has obviously appropriated, with
suspect selectivity, such libertarian themes as deregulation and voluntarism.
Ideologues indignant that Reagan has travestied their principles. Tough shit!
I notice that it's their principles, not mine, that he found suitable to
travesty."_ [**The Libertarian As Conservative**] This was echoed by Noam
Chomsky two decades later when while _"nobody takes [right-wing
libertarianism] seriously"_ as _"everybody knows that a society that worked by
. . . [its] principles would self-destruct in three seconds"_ the _"only
reason"_ why some people _"pretend to take it seriously is because you can use
it as a weapon."_ [**Understanding Power**, p. 200] As neo-liberalism is being
used as the ideological basis of the current attack on the working class,
critiquing "anarcho"-capitalism and right-libertarianism also allows use to
build theoretical weapons to use to resist this attack and aid the class
struggle.

A few more points before beginning. When debating with "libertarian" or
"anarchist" capitalists it's necessary to remember that while they claim "real
capitalism" does not exist (because all existing forms of capitalism are
statist), they will claim that all the good things we have -- advanced medical
technology, consumer choice of products, etc. -- are nevertheless due to
"capitalism." Yet if you point out any problems in modern life, these will be
blamed on "statism." Since there has never been and never will be a capitalist
system without some sort of state, it's hard to argue against this "logic."
Many actually use the example of the Internet as proof of the power of
"capitalism," ignoring the fact that the state paid for its development before
turning it over to companies to make a profit from it. Similar points can be
made about numerous other products of "capitalism" and the world we live in.
To artificially separate one aspect of a complex evolution fails to understand
the nature and history of the capitalist system.

In addition to this ability to be selective about the history and results of
capitalism, their theory has a great "escape clause." If wealthy employers
abuse their power or the rights of the working class (as they have always
done), then they have (according to "libertarian" ideology) ceased to be
capitalists! This is based upon the misperception that an economic system that
relies on force **cannot** be capitalistic. This is **very** handy as it can
absolve the ideology from blame for any (excessive) oppression which results
from its practice. Thus individuals are always to blame, **not** the system
that generated the opportunities for abuse they freely used.

Anarchism has always been aware of the existence of "free market" capitalism,
particularly its extreme (minimal state) wing, and has always rejected it. As
we discuss in [section 7](append137.html), anarchists from Proudhon onwards
have rejected the idea of any similar aims and goals (and, significantly, vice
versa). As academic Alan Carter notes, anarchist concern for equality as a
necessary precondition for genuine freedom means _"that is one very good
reason for not confusing anarchists with liberals or economic 'libertarians'
-- in other words, for not lumping together everyone who is in some way or
another critical of the state. It is why calling the likes of Nozick
'anarchists' is highly misleading."_ [_"Some notes on 'Anarchism'"_, pp.
141-5, **Anarchist Studies**, vol. 1, no. 2, p. 143] So anarchists have
evaluated "free market" capitalism and rejected it as non-anarchist for over
150 years. Attempts by "anarcho"-capitalism to say that their system is
"anarchist" flies in the face of this long history of anarchist analysis. That
some academics fall for their attempts to appropriate the anarchist label for
their ideology is down to a false premise: it _"is judged to be anarchism
largely because some anarcho-capitalists **say** they are 'anarchists' and
because they criticise the State."_ [Peter Sabatini, **Social Anarchism**, no.
23, p. 100]

More generally, we must stress that most (if not all) anarchists do not want
to live in a society **just like this one** but without state coercion and
(the initiation of) force. Anarchists do not confuse "freedom" with the
"right" to govern and exploit others nor with being able to change masters. It
is not enough to say we can start our own (co-operative) business in such a
society. We want the abolition of the capitalist system of authoritarian
relationships, not just a change of bosses or the possibility of little
islands of liberty within a sea of capitalism (islands which are always in
danger of being flooded and our activity destroyed). Thus, in this section of
the FAQ, we analysis many "anarcho"-capitalist claims on their own terms (for
example, the importance of equality in the market or why capitalism cannot be
reformed away by exchanges on the capitalist market) but that does not mean we
desire a society nearly identical to the current one. Far from it, we want to
transform this society into one more suited for developing and enriching
individuality and freedom. But before we can achieve that we must critically
evaluate the current society and point out its basic limitations.

Finally, we dedicate this section of the FAQ to those who have seen the real
face of "free market" capitalism at work: the working men and women (anarchist
or not) murdered in the jails and concentration camps or on the streets by the
hired assassins of capitalism.

[‹ Appendix - Is "anarcho"-capitalism a type of
anarchism?](/afaq/append13.html "Go to previous page" )
[up](/afaq/append13.html "Go to parent page" ) [1 Are "anarcho"-capitalists
really anarchists? ›](/afaq/append131.html "Go to next page" )

==> anarchism_15.3.orig.tar.gz: afaq-15.3/markdown/append13int.md <==
# Appendix - Is "anarcho"-capitalism a type of anarchism?

Anyone who has followed political discussion on the net has probably come
across people calling themselves libertarians but arguing from a right-wing,
pro-capitalist perspective. For most Europeans this is weird, as in Europe the
term _"libertarian"_ is almost always used in conjunction with _"socialist"_
or _"communist."_ In the US, though, the Right has partially succeeded in
appropriating this term for itself. Even stranger, however, is that a few of
these right-wingers have started calling themselves "anarchists" in what must
be one of the finest examples of an oxymoron in the English language:
'Anarcho-capitalist'!!

Arguing with fools is seldom rewarded, but to allow their foolishness to go
unchallenged risks allowing them to deceive those who are new to anarchism.
That's what this section of the anarchist FAQ is for, to show why the claims
of these "anarchist" capitalists are false. Anarchism has always been anti-
capitalist and any "anarchism" that claims otherwise cannot be part of the
anarchist tradition. So this section of the FAQ does not reflect some kind of
debate within anarchism, as many of these types like to pretend, but a debate
between anarchism and its old enemy, capitalism. In many ways this debate
mirrors the one between Peter Kropotkin and Herbert Spencer, an English pro-
capitalist, minimal statist, at the turn the 19th century and, as such, it is
hardly new.

The "anarcho"-capitalist argument hinges on using the dictionary definition of
"anarchism" and/or "anarchy" - they try to define anarchism as being
"opposition to government," and nothing else. However, dictionaries are hardly
politically sophisticated and their definitions rarely reflect the wide range
of ideas associated with political theories and their history. Thus the
dictionary "definition" is anarchism will tend to ignore its consistent views
on authority, exploitation, property and capitalism (ideas easily discovered
if actual anarchist texts are read). And, of course, many dictionaries
"define" anarchy as "chaos" or "disorder" but we never see
"anarcho"-capitalists use that particular definition!

And for this strategy to work, a lot of "inconvenient" history and ideas from
all branches of anarchism must be ignored. From individualists like Spooner
and Tucker to communists like Kropotkin and Malatesta, anarchists have always
been anti-capitalist (see [ section G](secGcon.md) for more on the anti-
capitalist nature of individualist anarchism). Therefore "anarcho"-capitalists
are not anarchists in the same sense that rain is not dry.

Of course, we cannot stop the "anarcho"-capitalists using the words "anarcho",
"anarchism" and "anarchy" to describe their ideas. The democracies of the west
could not stop the Chinese Stalinist state calling itself the People's
Republic of China. Nor could the social democrats stop the fascists in Germany
calling themselves "National Socialists". Nor could the Italian anarcho-
syndicalists stop the fascists using the expression "National Syndicalism".
This does not mean that any of these movements actual name reflected their
content -- China is a dictatorship, not a democracy, the Nazi's were not
socialists (capitalists made fortunes in Nazi Germany because it crushed the
labour movement), and the Italian fascist state had nothing in common with
anarcho-syndicalists ideas of decentralised, "from the bottom up" unions and
the abolition of the state and capitalism.

Therefore, just because someone uses a label it does not mean that they
support the ideas associated with that label. And this is the case with
"anarcho"-capitalism -- its ideas are at odds with the key ideas associated
with all forms of traditional anarchism (even individualist anarchism which is
often claimed as being a forefather of the ideology).

All we can do is indicate **why** "anarcho"-capitalism is not part of the
anarchist tradition and so has falsely appropriated the name. This section of
the FAQ aims to do just that -- present the case why "anarcho"-capitalists are
not anarchists. We do this, in part, by indicating where they differ from
genuine anarchists (on such essential issues as private property, equality,
exploitation and opposition to hierarchy) In addition, we take the opportunity
to present a general critique of right-libertarian claims from an anarchist
perspective. In this way we show up why anarchists reject that theory as being
opposed to liberty and anarchist ideals.

We are covering this topic in an anarchist FAQ for three reasons. Firstly, the
number of "libertarian" and "anarcho"-capitalists on the net means that those
seeking to find out about anarchism may conclude that they are "anarchists" as
well. Secondly, unfortunately, some academics and writers have taken their
claims of being anarchists at face value and have included their ideology into
general accounts of anarchism. These two reasons are obviously related and
hence the need to show the facts of the matter. As we have extensively
documented in earlier sections, anarchist theory has always been anti-
capitalist. There is no relationship between anarchism and capitalism, in any
form. Therefore, there is a need for this section in order to indicate exactly
why "anarcho"-capitalism is not anarchist. As will be quickly seen from our
discussion, almost all anarchists who become aware of "anarcho"-capitalism
quickly reject it as a form of anarchism (the better academic accounts do note
that anarchists generally reject the claim, though). The last reason is to
provide other anarchists with arguments and evidence to use against
"anarcho"-capitalism and its claims of being a new form of "anarchism."

So this section of the FAQ does not, as we noted above, represent some kind of
"debate" within anarchism. It reflects the attempt by anarchists to reclaim
the history and meaning of anarchism from those who are attempting to steal
its name (just as right-wingers in America have attempted to appropriate the
name "libertarian" for their pro-capitalist views, and by so doing ignore over
100 years of anti-capitalist usage). However, this section also serves two
other purposes. Firstly, critiquing right-libertarian and "anarcho"-capitalist
theories allows us to explain anarchist ones at the same time and indicate why
they are better. Secondly, and more importantly, the "ideas" and "ideals" that
underlie "anarcho"-capitalism are usually identical (or, at the very least,
similar) to those of neo-liberalism. This was noted by Bob Black in the early
1980s, when a _"wing of the Reaganist Right has obviously appropriated, with
suspect selectivity, such libertarian themes as deregulation and voluntarism.
Ideologues indignant that Reagan has travestied their principles. Tough shit!
I notice that it's their principles, not mine, that he found suitable to
travesty."_ [ **The Libertarian As Conservative** ] This was echoed by Noam
Chomsky two decades later when while _"nobody takes [right-wing
libertarianism] seriously"_ as _"everybody knows that a society that worked by
. . . [its] principles would self-destruct in three seconds"_ the _"only
reason"_ why some people _"pretend to take it seriously is because you can use
it as a weapon."_ [ **Understanding Power** , p. 200] As neo-liberalism is
being used as the ideological basis of the current attack on the working
class, critiquing "anarcho"-capitalism and right-libertarianism also allows
use to build theoretical weapons to use to resist this attack and aid the
class struggle.

A few more points before beginning. When debating with "libertarian" or
"anarchist" capitalists it's necessary to remember that while they claim "real
capitalism" does not exist (because all existing forms of capitalism are
statist), they will claim that all the good things we have -- advanced medical
technology, consumer choice of products, etc. -- are nevertheless due to
"capitalism." Yet if you point out any problems in modern life, these will be
blamed on "statism." Since there has never been and never will be a capitalist
system without some sort of state, it's hard to argue against this "logic."
Many actually use the example of the Internet as proof of the power of
"capitalism," ignoring the fact that the state paid for its development before
turning it over to companies to make a profit from it. Similar points can be
made about numerous other products of "capitalism" and the world we live in.
To artificially separate one aspect of a complex evolution fails to understand
the nature and history of the capitalist system.

In addition to this ability to be selective about the history and results of
capitalism, their theory has a great "escape clause." If wealthy employers
abuse their power or the rights of the working class (as they have always
done), then they have (according to "libertarian" ideology) ceased to be
capitalists! This is based upon the misperception that an economic system that
relies on force **cannot** be capitalistic. This is **very** handy as it can
absolve the ideology from blame for any (excessive) oppression which results
from its practice. Thus individuals are always to blame, **not** the system
that generated the opportunities for abuse they freely used.

Anarchism has always been aware of the existence of "free market" capitalism,
particularly its extreme (minimal state) wing, and has always rejected it. As
we discuss in [section 7](append137.md), anarchists from Proudhon onwards
have rejected the idea of any similar aims and goals (and, significantly, vice
versa). As academic Alan Carter notes, anarchist concern for equality as a
necessary precondition for genuine freedom means _"that is one very good
reason for not confusing anarchists with liberals or economic 'libertarians'
-- in other words, for not lumping together everyone who is in some way or
another critical of the state. It is why calling the likes of Nozick
'anarchists' is highly misleading."_ [ _"Some notes on 'Anarchism'"_ , pp.
141-5, **Anarchist Studies** , vol. 1, no. 2, p. 143] So anarchists have
evaluated "free market" capitalism and rejected it as non-anarchist for over
150 years. Attempts by "anarcho"-capitalism to say that their system is
"anarchist" flies in the face of this long history of anarchist analysis. That
some academics fall for their attempts to appropriate the anarchist label for
their ideology is down to a false premise: it _"is judged to be anarchism
largely because some anarcho-capitalists **say** they are 'anarchists' and
because they criticise the State."_ [Peter Sabatini, **Social Anarchism** ,
no. 23, p. 100]

More generally, we must stress that most (if not all) anarchists do not want
to live in a society **just like this one** but without state coercion and
(the initiation of) force. Anarchists do not confuse "freedom" with the
"right" to govern and exploit others nor with being able to change masters. It
is not enough to say we can start our own (co-operative) business in such a
society. We want the abolition of the capitalist system of authoritarian
relationships, not just a change of bosses or the possibility of little
islands of liberty within a sea of capitalism (islands which are always in
danger of being flooded and our activity destroyed). Thus, in this section of
the FAQ, we analysis many "anarcho"-capitalist claims on their own terms (for
example, the importance of equality in the market or why capitalism cannot be
reformed away by exchanges on the capitalist market) but that does not mean we
desire a society nearly identical to the current one. Far from it, we want to
transform this society into one more suited for developing and enriching
individuality and freedom. But before we can achieve that we must critically
evaluate the current society and point out its basic limitations.

Finally, we dedicate this section of the FAQ to those who have seen the real
face of "free market" capitalism at work: the working men and women (anarchist
or not) murdered in the jails and concentration camps or on the streets by the
hired assassins of capitalism.

[‹ Appendix - Is "anarcho"-capitalism a type of anarchism?](append13.md "Go
to previous page") [up](append13.md "Go to parent page") [1 Are
"anarcho"-capitalists really anarchists? ›](append131.md "Go to next page")
